package com.bonus.material.push.mapper;

import java.util.List;
import com.bonus.material.push.domain.PushDataReceiveDetail;

/**
 * 推送接收明细Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface PushDataReceiveDetailMapper {
    /**
     * 查询推送接收明细
     * 
     * @param id 推送接收明细主键
     * @return 推送接收明细
     */
    public PushDataReceiveDetail selectPushDataReceiveDetailById(Long id);

    /**
     * 查询推送接收明细列表
     * 
     * @param pushDataReceiveDetail 推送接收明细
     * @return 推送接收明细集合
     */
    public List<PushDataReceiveDetail> selectPushDataReceiveDetailList(PushDataReceiveDetail pushDataReceiveDetail);

    /**
     * 新增推送接收明细
     * 
     * @param pushDataReceiveDetail 推送接收明细
     * @return 结果
     */
    public int insertPushDataReceiveDetail(PushDataReceiveDetail pushDataReceiveDetail);

    /**
     * 修改推送接收明细
     * 
     * @param pushDataReceiveDetail 推送接收明细
     * @return 结果
     */
    public int updatePushDataReceiveDetail(PushDataReceiveDetail pushDataReceiveDetail);

    /**
     * 删除推送接收明细
     * 
     * @param id 推送接收明细主键
     * @return 结果
     */
    public int deletePushDataReceiveDetailById(Long id);

    /**
     * 批量删除推送接收明细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePushDataReceiveDetailByIds(Long[] ids);
}
