package com.bonus.material.push.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.push.domain.PushDataReceiveDetail;
import com.bonus.material.push.service.IPushDataReceiveDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 推送接收明细Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "推送接收明细接口")
@RestController
@RequestMapping("/push_data_receive_detail")
public class PushDataReceiveDetailController extends BaseController {
    @Autowired
    private IPushDataReceiveDetailService pushDataReceiveDetailService;

    /**
     * 查询推送接收明细列表
     */
    @ApiOperation(value = "查询推送接收明细列表")
    @RequiresPermissions("push:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(PushDataReceiveDetail pushDataReceiveDetail) {
        startPage();
        List<PushDataReceiveDetail> list = pushDataReceiveDetailService.selectPushDataReceiveDetailList(pushDataReceiveDetail);
        return getDataTable(list);
    }

    /**
     * 导出推送接收明细列表
     */
    @ApiOperation(value = "导出推送接收明细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("push:detail:export")
    @SysLog(title = "推送接收明细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出推送接收明细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PushDataReceiveDetail pushDataReceiveDetail) {
        List<PushDataReceiveDetail> list = pushDataReceiveDetailService.selectPushDataReceiveDetailList(pushDataReceiveDetail);
        ExcelUtil<PushDataReceiveDetail> util = new ExcelUtil<PushDataReceiveDetail>(PushDataReceiveDetail.class);
        util.exportExcel(response, list, "推送接收明细数据");
    }

    /**
     * 获取推送接收明细详细信息
     */
    @ApiOperation(value = "获取推送接收明细详细信息")
    @RequiresPermissions("push:detail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(pushDataReceiveDetailService.selectPushDataReceiveDetailById(id));
    }

    /**
     * 新增推送接收明细
     */
    @ApiOperation(value = "新增推送接收明细")
    @PreventRepeatSubmit
    @RequiresPermissions("push:detail:add")
    @SysLog(title = "推送接收明细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增推送接收明细")
    @PostMapping
    public AjaxResult add(@RequestBody PushDataReceiveDetail pushDataReceiveDetail) {
        try {
            return toAjax(pushDataReceiveDetailService.insertPushDataReceiveDetail(pushDataReceiveDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改推送接收明细
     */
    @ApiOperation(value = "修改推送接收明细")
    @PreventRepeatSubmit
    @RequiresPermissions("push:detail:edit")
    @SysLog(title = "推送接收明细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改推送接收明细")
    @PutMapping
    public AjaxResult edit(@RequestBody PushDataReceiveDetail pushDataReceiveDetail) {
        try {
            return toAjax(pushDataReceiveDetailService.updatePushDataReceiveDetail(pushDataReceiveDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除推送接收明细
     */
    @ApiOperation(value = "删除推送接收明细")
    @PreventRepeatSubmit
    @RequiresPermissions("push:detail:remove")
    @SysLog(title = "推送接收明细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除推送接收明细")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(pushDataReceiveDetailService.deletePushDataReceiveDetailByIds(ids));
    }
}
